==> ideaIC-191.6707.61-sources.jar: org/jetbrains/idea/maven/externalSystemIntegration/output/MavenOutputParserProvider.java <==
// Copyright 2000-2019 JetBrains s.r.o. Use of this source code is governed by the Apache 2.0 license that can be found in the LICENSE file.
package org.jetbrains.idea.maven.externalSystemIntegration.output;

import com.intellij.build.output.BuildOutputParser;
import com.intellij.openapi.externalSystem.model.ProjectSystemId;
import com.intellij.openapi.externalSystem.model.task.ExternalSystemTask;
import com.intellij.openapi.externalSystem.model.task.ExternalSystemTaskId;
import com.intellij.openapi.externalSystem.service.execution.ExternalSystemOutputParserProvider;
import com.intellij.util.containers.ContainerUtil;
import org.jetbrains.annotations.ApiStatus;
import org.jetbrains.idea.maven.externalSystemIntegration.output.events.*;
import org.jetbrains.idea.maven.utils.MavenUtil;

import java.util.List;

@ApiStatus.Experimental
public class MavenOutputParserProvider implements ExternalSystemOutputParserProvider {
  @Override
  public ProjectSystemId getExternalSystemId() {
    return MavenUtil.SYSTEM_ID;
  }

  @Override
  public List<BuildOutputParser> getBuildOutputParsers(ExternalSystemTask task) {
    return ContainerUtil.list(createMavenOutputParser(task.getId()));
  }

  public static MavenLogOutputParser createMavenOutputParser(ExternalSystemTaskId taskId) {
    return new MavenLogOutputParser(taskId,
                                    ContainerUtil.list(
                                      new ArtifactDownloadScanning(),
                                      new JavaBuildErrorNotification(),
                                      new KotlinBuildErrorNotification(),
                                      new ProjectScanning(),
                                      new WarningNotifier(),
                                      new CommonErrorParser()
                                    ));
  }
}

==> ideaIC-201.6668.113-sources.jar: org/jetbrains/idea/maven/externalSystemIntegration/output/MavenOutputParserProvider.java <==
// Copyright 2000-2019 JetBrains s.r.o. Use of this source code is governed by the Apache 2.0 license that can be found in the LICENSE file.
package org.jetbrains.idea.maven.externalSystemIntegration.output;

import com.intellij.build.output.BuildOutputParser;
import com.intellij.openapi.externalSystem.model.ProjectSystemId;
import com.intellij.openapi.externalSystem.model.task.ExternalSystemTaskId;
import com.intellij.openapi.externalSystem.service.execution.ExternalSystemOutputParserProvider;
import org.jetbrains.annotations.ApiStatus;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.idea.maven.externalSystemIntegration.output.parsers.*;
import org.jetbrains.idea.maven.utils.MavenUtil;

import java.util.Arrays;
import java.util.List;

@ApiStatus.Experimental
public class MavenOutputParserProvider implements ExternalSystemOutputParserProvider {
  @Override
  public ProjectSystemId getExternalSystemId() {
    return MavenUtil.SYSTEM_ID;
  }

  @Override
  public List<BuildOutputParser> getBuildOutputParsers(@NotNull ExternalSystemTaskId taskId) {
    throw new UnsupportedOperationException();
  }

  public static MavenLogOutputParser createMavenOutputParser(ExternalSystemTaskId taskId) {
    return new MavenLogOutputParser(taskId,
                                    Arrays.asList( new JavaBuildErrorNotification(),
                                                   new KotlinBuildErrorNotification(),
                                                   new WarningNotifier(),

                                                   new MavenBadConfigEventParser()));
  }
}
